@@ -1,6 +1,7 @@
 use crate::storage_layer::JsonStorage;
 use serde::ser::{SerializeMap, Serializer};
 use serde_json::Value;
+use std::collections::HashMap;
 use std::fmt;
 use std::io::Write;
 use tracing::{Event, Id, Subscriber};
@@ -46,6 +47,7 @@ pub struct BunyanFormattingLayer<W: for<'a> MakeWriter<'a> + 'static> {
     hostname: String,
     bunyan_version: u8,
     name: String,
+    default_fields: HashMap<String, Value>,
 }
 
 impl<W: for<'a> MakeWriter<'a> + 'static> BunyanFormattingLayer<W> {
@@ -69,12 +71,17 @@ impl<W: for<'a> MakeWriter<'a> + 'static> BunyanFormattingLayer<W> {
     /// let formatting_layer = BunyanFormattingLayer::new("tracing_example".into(), || std::io::stdout());
     /// ```
     pub fn new(name: String, make_writer: W) -> Self {
+        Self::with_default_fields(name, make_writer, HashMap::new())
+    }
+
+    pub fn with_default_fields(name: String, make_writer: W, default_fields: HashMap<String, Value>) -> Self {
         Self {
             make_writer,
             name,
             pid: std::process::id(),
             hostname: gethostname::gethostname().to_string_lossy().into_owned(),
             bunyan_version: 0,
+            default_fields,
         }
     }
 
@@ -114,6 +121,18 @@ impl<W: for<'a> MakeWriter<'a> + 'static> BunyanFormattingLayer<W> {
         map_serializer.serialize_entry("line", &span.metadata().line())?;
         map_serializer.serialize_entry("file", &span.metadata().file())?;
 
+        // Add all default fields
+        for (key, value) in self.default_fields.iter() {
+            if !BUNYAN_RESERVED_FIELDS.contains(&key.as_str()) {
+                map_serializer.serialize_entry(key, value)?;
+            } else {
+                tracing::debug!(
+                        "{} is a reserved field in the bunyan log format. Skipping it.",
+                        key
+                    );
+            }
+        }
+
         let extensions = span.extensions();
         if let Some(visitor) = extensions.get::<JsonStorage>() {
             for (key, value) in visitor.values() {
@@ -237,6 +256,14 @@ where
             map_serializer.serialize_entry("line", &event.metadata().line())?;
             map_serializer.serialize_entry("file", &event.metadata().file())?;
 
+            // Add all default fields
+            for (key, value) in self.default_fields
+                .iter()
+                .filter(|(key, _)| key.as_str() != "message" && !BUNYAN_RESERVED_FIELDS.contains(&key.as_str()))
+            {
+                map_serializer.serialize_entry(key, value)?;
+            }
+
             // Add all the other fields associated with the event, expect the message we already used.
             for (key, value) in event_visitor
                 .values()
